Test Modal Dialog

TestModalDialog (Only works in IE)
open | ../tests/html/test_modal_dialog.html |
verifyLocation | */tests/html/test_modal_dialog.html |
verifyTitle | Modal Dialog Host Window |
verifyValue | changeText | before modal dialog
click | modal |
waitForPopup | Modal Dialog Popup | 5000
selectWindow | Modal Dialog Popup |
verifyTitle | Modal Dialog Popup |
click | change |
click | close |
selectWindow | Modal Dialog Host Window |
verifyValue | changeText | after modal dialog
verifyTitle | Modal Dialog Popup |